@@ -2,13 +2,18 @@
 
 global $blocked;
 
-$allowblockeddownloads = false;
+$virusscan = 1;
+
+$excluded = Array('jimmy@advcs.org');
 
 $blocked = Array('bat',
 'com',
-'exe',
+'js',
+'mp3',
 'pif',
 'scr',
 'vbs');
 
+$warning = Array('exe');
+
 ?>
\ No newline at end of file
