@@ -5,20 +5,24 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.1
+    Version ........ 0.3
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
 
    global $optpage_blocks, $username;
 
-   include_once(SM_PATH . 'plugins/block_attach/admins.php');
-   if (!in_array($username,$admin)) return;
-
-    $optpage_blocks[] = array (
+   if (!function_exists('adm_check_user'))
+      include_once(SM_PATH . 'plugins/block_attach/includes/auth.php');
+   $auth = adm_check_user();
+   if (!$auth) return;
+   bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
+   textdomain('block_attach');
+   $optpage_blocks[] = array (
         'name' => _("Block Attachments"),
         'url'  => SM_PATH . 'plugins/block_attach/options.php',
         'desc' => _("These settings allow you to block certain types of attachments."),
         'js'   => false
-    );
+   );
+   textdomain('squirrelmail');
 ?>
\ No newline at end of file
